dm: led: Rename struct led_uclass_plat

These structures are normally named with 'uc' instead of 'uclass'. Change
this one for consistency.

Signed-off-by: Simon Glass <sjg@chromium.org>
Reviewed-by: Ziping Chen <techping.chan@gmail.com>
diff --git a/include/led.h b/include/led.h
index b929d0c..a856b3d 100644
--- a/include/led.h
+++ b/include/led.h
@@ -9,11 +9,11 @@
 #define __LED_H
 
 /**
  * struct led_uclass_plat - Platform data the uclass stores about each device
  *
  * @label:	LED label
  */
-struct led_uclass_plat {
+struct led_uc_plat {
 	const char *label;
 };
@@ -9,11 +9,11 @@
 
 /**
- * struct led_uclass_plat - Platform data the uclass stores about each device
+ * struct led_uc_plat - Platform data the uclass stores about each device
  *
  * @label:	LED label